# Sample Code

Build instructions can be found at the top of each code file.

Some models may need to be downloaded to be loaded at runtime (running the inference function will throw an error if the model is not found). For these models, run the scripts located in the `download_models` directory to obtain the models. Be sure to specify the `modelsPath` configuration option.

`${LICENSE_CODE}` must be replaced with your license code.

### Face Recognition - 1 to 1 Identification
`face_recognition.cpp` demonstrates the usage of our face recognition API. A convinient method is provided that loads images, `setImage()`. This method can decode JPEG, PNG, BMP and PPM images. Note you will need to run the download script in /download_models to obtain the TFV5 model file.

`face_recognition_full_model.cpp` demonstrates the usage of our face recognition API, using our most accurate FR model, TFV5. This model has better accuracy, at the cost of increased inference time. Note you will need to run the download script in /download_models to obtain the TFV5 model file.

`face_recognition_image_buffer.cpp` uses the overloaded `setImage()` method that takes the pointer to a decoded image buffer in memory. 
The main usecase is processing frames grabed from a camera without writing them into a file. Note you will need to run the download script in /download_models to obtain the TFV5 model file.

### Face Recognition - 1 to N Identification
`identification.cpp` demonstrates the usage of our 1:N matcher. The `createDatabaseConnection` and `createLoadCollection` functions are first used to connect to an existing or new database, then create a new collection or populate data from an existing collection. Next, templates are enrolled into the collection using the `enrollFaceprint` function.
Finally, the collection can be queried using the `identifyTopCandidate` and `identifyTopCandidates` functions. Consult the header for other 1 to N functions. 

To save templates even after the application is terminated, change the `dbms` configuration option to a database option such as `SQLITE`

Note you will need to run the download script in /download_models to obtain the TFV5 model file.

### Object Detection ##
`object_detection.cpp` demonstrates the usage of our object detector.

### Liveness
`blink_detection.cpp` demonstrates how to detect blinks, and can be used for liveness detection.

### Spoof Detection
`spoof_detection.cpp` demonstrates how to identify presentation attacks. Note you will need to run the download script in /download_models to obtain the spoof model file.

### Mask Detection
`detect_mask.cpp` demonstrates how to run mask detection on an image. Mask is detected when a user is wearing a face mask.

### Eye glasses Detection
`detect_eyeglasses.cpp` demonstrates how to run eye glasses detection on an image. Glasses are detected when a user is wearing some type of glasses.

### Batch Inference
`batch_fr_cuda.cpp` demonstrates how to generate face feature vectors in batch when using the GPU library. 

### VRam
`face_detect_image_in_vram.cpp` Using the GPU/CUDA backend detect largest face in an image already loaded in the graphics card's memory. You will need to have opencv cuda installed to run this sample app.

### Live Streaming
There are many live streaming examples on our [Sample Apps Page](https://github.com/getchui/sample-apps) under `/cpp_sdk`
These require you to have OpenCV installed on your system. 
